@@ -95,7 +95,7 @@ class Server(object):
             self.host, self.port = sockname[0], sockname[1]
 
         if logger is None:
-            logger = logging.getLogger("%s/%s" % (self.service.get_service_name(), self.port))
+            logger = logging.getLogger(f"{self.service.get_service_name()}/{self.port}")
         self.logger = logger
         if "logger" not in self.protocol_config:
             self.protocol_config["logger"] = self.logger
@@ -153,7 +153,7 @@ class Server(object):
             return
 
         sock.setblocking(True)
-        self.logger.info("accepted %s with fd %s", addrinfo, sock.fileno())
+        self.logger.info(f"accepted {addrinfo} with fd {sock.fileno()}")
         self.clients.add(sock)
         self._accept_method(sock)
 
@@ -171,10 +171,10 @@ class Server(object):
                 try:
                     sock2, credentials = self.authenticator(sock)
                 except AuthenticationError:
-                    self.logger.info("%s failed to authenticate, rejecting connection", addrinfo)
+                    self.logger.info(f"{addrinfo} failed to authenticate... rejecting connection")
                     return
                 else:
-                    self.logger.info("%s authenticated successfully", addrinfo)
+                    self.logger.info(f"{addrinfo} authenticated successfully")
             else:
                 credentials = None
                 sock2 = sock
@@ -194,16 +194,16 @@ class Server(object):
     def _serve_client(self, sock, credentials):
         addrinfo = sock.getpeername()
         if credentials:
-            self.logger.info("welcome %s (%r)", addrinfo, credentials)
+            self.logger.info(f"welcome {addrinfo} ({credentials!r})")
         else:
-            self.logger.info("welcome %s", addrinfo)
+            self.logger.info(f"welcome {addrinfo}")
         try:
             config = dict(self.protocol_config, credentials=credentials,
                           endpoints=(sock.getsockname(), addrinfo), logger=self.logger)
             conn = self.service._connect(Channel(SocketStream(sock)), config)
             self._handle_connection(conn)
         finally:
-            self.logger.info("goodbye %s", addrinfo)
+            self.logger.info(f"goodbye {addrinfo}")
 
     def _handle_connection(self, conn):
         """This methoed should implement the server's logic."""
@@ -212,7 +212,7 @@ class Server(object):
     def _bg_register(self):
         interval = self.registrar.REREGISTER_INTERVAL
         self.logger.info("started background auto-register thread "
-                         "(interval = %s)", interval)
+                         f"(interval = {interval})")
         tnext = 0
         try:
             while self.active:
@@ -247,12 +247,11 @@ class Server(object):
             # Note that for AF_UNIX the following won't work (but we are safe
             # since we already saved the socket_path into self.port):
             self.port = self.listener.getsockname()[1]
-        self.logger.info("server started on [%s]:%s", self.host, self.port)
+        self.logger.info(f"server started on [{self.host}]:{self.port}")
         self.active = True
 
     def _register(self):
         if self.auto_register:
-            self.auto_register = False
             spawn(self._bg_register)
 
     def start(self):
@@ -342,7 +341,7 @@ class ThreadPoolServer(Server):
         self.workers = []
         for i in range(self.nbthreads):
             t = spawn(self._serve_clients)
-            t.setName('Worker%i' % i)
+            t.setName(f"Worker{i}")
             self.workers.append(t)
         # setup a thread for polling inactive connections
         self.polling_thread = spawn(self._poll_inactive_clients)
@@ -383,7 +382,7 @@ class ThreadPoolServer(Server):
             pass
 
         # close connection
-        self.logger.info("Closing connection for fd %d", fd)
+        self.logger.info(f"Closing connection for fd {fd}")
         if conn:
             conn.close()
 
@@ -421,7 +420,7 @@ class ThreadPoolServer(Server):
             except Exception:
                 ex = sys.exc_info()[1]
                 # "Caught exception in Worker thread" message
-                self.logger.warning("Failed to poll clients, caught exception : %s", str(ex))
+                self.logger.warning(f"Failed to poll clients, caught exception : {ex}")
                 # wait a bit so that we do not loop too fast in case of error
                 time.sleep(0.2)
 
@@ -493,7 +492,7 @@ class ThreadPoolServer(Server):
             # put the connection in the active queue
             addrinfo = sock.getpeername()
             fd = conn.fileno()
-            self.logger.debug("Created connection to %s with fd %d", addrinfo, fd)
+            self.logger.debug("Created connection to {addrinfo} with fd {fd}")
             self.fd_to_conn[fd] = conn
             self._add_inactive_connection(fd)
             self.clients.clear()
@@ -565,7 +564,6 @@ class GeventServer(Server):
 
     def _register(self):
         if self.auto_register:
-            self.auto_register = False
             gevent.spawn(self._bg_register)
 
     def _accept_method(self, sock):
